# Get the computer name
$computerName = $env:COMPUTERNAME

# Get the operating system information
$osInfo = Get-CimInstance Win32_OperatingSystem | Select-Object Caption, Version, InstallDate

# Convert OS_InstallDate to a date with no time component
$osInstallDate = $osInfo.InstallDate
$osInstallDate = Get-Date $osInstallDate -Format "yyyy-MM-dd"

# Get the computer system information
$computerSystem = Get-CimInstance Win32_ComputerSystem | Select-Object Manufacturer, Model, TotalPhysicalMemory

# Get the processor information
$processor = Get-CimInstance Win32_Processor | Select-Object Name, NumberOfCores

# Get the GPU information
$gpu = Get-CimInstance Win32_VideoController | Select-Object Caption, @{Name="AdapterRAM(GB)"; Expression={[math]::Round($_.AdapterRAM / 1GB, 2)}}

# Get the drive information
$drives = Get-WmiObject Win32_DiskDrive | Select-Object @{Name="DriveCaption"; Expression={"$($_.Caption)"}}, @{Name="Size(GB)"; Expression={[math]::Round($_.Size / 1GB, 2)}}

# Create a custom object to store the information
$customSystemInfo = [PSCustomObject]@{
    "Computer_Name" = $computerName
    "OS" = $osInfo.Caption
    "OS_Version" = $osInfo.Version
    "OS_InstallDate" = $osInstallDate
    "Manufacturer" = $computerSystem.Manufacturer
    "Model" = $computerSystem.Model
    "Memory" = "$([math]::Round($computerSystem.TotalPhysicalMemory / 1GB, 2)) GB"
    "CPU" = $processor.Name
    "CPU_NumberOfCores" = $processor.NumberOfCores
    "GPU" = $gpu.Caption
    "GPU_RAM" = "$($gpu.'AdapterRAM(GB)') GB"
}

# Create an array to store drive information
$driveInfoArray = @()

# Add drive information to the array
foreach ($drive in $drives) {
    $driveCaption = $drive."DriveCaption"
    $driveSizeGB = $drive."Size(GB)"

    $driveInfo = "$driveCaption ($driveSizeGB GB)"
    $driveInfoArray += $driveInfo
}

# Convert the array of drive information into a single string
$driveInfoString = $driveInfoArray -join ", "
$customSystemInfo | Add-Member -MemberType NoteProperty -Name "Hard_Drives" -Value $driveInfoString

# Display the custom system information
$customSystemInfo

# Export the custom system information to a CSV file
$csvFilePath = "myComputerSpecs.csv"
$customSystemInfo | Export-Csv -Path $csvFilePath -NoTypeInformation
Write-Host "Custom system information exported to $csvFilePath"
